@@ -1,14 +1,14 @@
 #' @title Set components names for vector names
 #'
 #' @description
-#' If param has \code{cnames} set component names in a value.
-#' Otherwise \code{x} is left unchanged.
+#' If param has `cnames` set component names in a value.
+#' Otherwise `x` is left unchanged.
 #'
 #' @template arg_par_or_set
-#' @param x [any] \cr
+#' @param x (any) \cr
 #'   Param value(s).
 #'   For a parameter set this must be a list in the correct order.
-#' @return \code{x} with changed names.
+#' @return `x` with changed names.
 #' @export
 setValueCNames = function(par, x) {
   UseMethod("setValueCNames")
@@ -17,8 +17,9 @@ setValueCNames = function(par, x) {
 #' @export
 setValueCNames.Param = function(par, x) {
   # do not set names for missing / req.params
-  if (par$type %fin% ph$value.component.names && !isScalarNA(x))
+  if (par$type %fin% ph$value.component.names && !isScalarNA(x)) {
     names(x) = par$cnames
+  }
   return(x)
 }
 
