@@ -6,13 +6,10 @@
 
 /* .Call calls */
 extern SEXP c_dfRowsToList(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP c_generateDesign(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP c_trafo_and_set_dep_to_na(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"c_dfRowsToList",            (DL_FUNC) &c_dfRowsToList,            6},
-    {"c_generateDesign",          (DL_FUNC) &c_generateDesign,          6},
-    {"c_trafo_and_set_dep_to_na", (DL_FUNC) &c_trafo_and_set_dep_to_na, 7},
     {NULL, NULL, 0}
 };
 
